# ActivityLogTreeNode

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**started** | **datetime** |  | [optional] 
**ended** | **datetime** |  | [optional] 
**status** | **str** |  | [optional] 
**show_at_summary_level** | **bool** |  | [optional] 
**progress_percentage** | **int** |  | [optional] 
**progress_message** | **str** |  | [optional] 
**children** | [**list[ActivityLogTreeNode]**](ActivityLogTreeNode.md) |  | [optional] 
**log_elements** | [**list[ActivityLogEntry]**](ActivityLogEntry.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


